==> jc-1.4.0.tar.gz: jasmin/ReservedWords.h <==
// abstract class jasmin.ReservedWords

// class file dependencies
// @dep_class 555aa2ca38adfa43 jasmin_ReservedWords
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_jasmin_ReservedWords_H_
#define _JC_jasmin_ReservedWords_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Hashtable$object;
struct _jc_java__5fcup_runtime_Symbol$object;

// Typedefs
typedef struct _jc_jasmin_ReservedWords$sub_refs	_jc_jasmin_ReservedWords$sub_refs;
typedef struct _jc_jasmin_ReservedWords$sub_nonrefs	_jc_jasmin_ReservedWords$sub_nonrefs;
typedef struct _jc_jasmin_ReservedWords$refs	_jc_jasmin_ReservedWords$refs;
typedef struct _jc_jasmin_ReservedWords$nonrefs	_jc_jasmin_ReservedWords$nonrefs;
typedef struct _jc_jasmin_ReservedWords$object	_jc_jasmin_ReservedWords$object;

typedef struct _jc_jasmin_ReservedWords$fields_struct	_jc_jasmin_ReservedWords$fields_struct;
typedef const struct _jc_jasmin_ReservedWords$vmethods	_jc_jasmin_ReservedWords$vmethods;
typedef const struct _jc_jasmin_ReservedWords$vtable	_jc_jasmin_ReservedWords$vtable;
typedef const struct _jc_jasmin_ReservedWords$vtype	_jc_jasmin_ReservedWords$vtype;

// Class fields structure
struct _jc_jasmin_ReservedWords$fields_struct {
	struct _jc_java_util_Hashtable$object	*reserved__5fwords;
};
extern _jc_jasmin_ReservedWords$fields_struct _jc_jasmin_ReservedWords$class_fields;

// Constructors
extern void _jc_jasmin_ReservedWords$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_jasmin_ReservedWords$object *);

// Static methods
extern void _jc_jasmin_ReservedWords$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern jboolean _jc_jasmin_ReservedWords$method$contains$14daef07ea176c5a(_jc_env *, struct _jc_java_lang_String$object *);
extern struct _jc_java__5fcup_runtime_Symbol$object *_jc_jasmin_ReservedWords$method$get$009a89eb3c60e5cc(_jc_env *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_jasmin_ReservedWords$vmethods {
};

// Vtable
struct _jc_jasmin_ReservedWords$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jasmin_ReservedWords$vmethods	jasmin_ReservedWords;
};

// Vtype
struct _jc_jasmin_ReservedWords$vtype {
	_jc_type			type;
	_jc_jasmin_ReservedWords$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jasmin_ReservedWords$sub_refs {
};

// Reference instance fields (object)
struct _jc_jasmin_ReservedWords$refs {
    _jc_jasmin_ReservedWords$sub_refs	jasmin_ReservedWords;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jasmin_ReservedWords$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_jasmin_ReservedWords$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jasmin_ReservedWords$sub_nonrefs	jasmin_ReservedWords;
};

// Object instance structure
struct _jc_jasmin_ReservedWords$object {
	_jc_jasmin_ReservedWords$refs	refs[0];
	_jc_word		lockword;
	_jc_jasmin_ReservedWords$vtype	*vtype;
	_jc_jasmin_ReservedWords$nonrefs	nonrefs;
};

// Type structure
extern _jc_jasmin_ReservedWords$vtype _jc_jasmin_ReservedWords$type;

// Array types class info structures
_JC_DECL_ARRAYS(jasmin_ReservedWords, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jasmin_ReservedWords$class_object;

#endif	/* _JC_jasmin_ReservedWords_H_ */

==> jc-1.4.6.tar.gz: jasmin/ReservedWords.h <==
// abstract class jasmin.ReservedWords

// class file dependencies
// @dep_class 555aa2ca38adfa43 jasmin_ReservedWords
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_jasmin_ReservedWords_H_
#define _JC_jasmin_ReservedWords_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Hashtable$object;
struct _jc_java__5fcup_runtime_Symbol$object;

// Typedefs
typedef struct _jc_jasmin_ReservedWords$sub_refs	_jc_jasmin_ReservedWords$sub_refs;
typedef struct _jc_jasmin_ReservedWords$sub_nonrefs	_jc_jasmin_ReservedWords$sub_nonrefs;
typedef struct _jc_jasmin_ReservedWords$refs	_jc_jasmin_ReservedWords$refs;
typedef struct _jc_jasmin_ReservedWords$nonrefs	_jc_jasmin_ReservedWords$nonrefs;
typedef struct _jc_jasmin_ReservedWords$object	_jc_jasmin_ReservedWords$object;

typedef struct _jc_jasmin_ReservedWords$fields_struct	_jc_jasmin_ReservedWords$fields_struct;
typedef const struct _jc_jasmin_ReservedWords$vmethods	_jc_jasmin_ReservedWords$vmethods;
typedef const struct _jc_jasmin_ReservedWords$vtable	_jc_jasmin_ReservedWords$vtable;
typedef const struct _jc_jasmin_ReservedWords$vtype	_jc_jasmin_ReservedWords$vtype;

// Class fields structure
struct _jc_jasmin_ReservedWords$fields_struct {
	struct _jc_java_util_Hashtable$object	*reserved__5fwords;
};
extern _jc_jasmin_ReservedWords$fields_struct _jc_jasmin_ReservedWords$class_fields;

// Constructors
extern void _jc_jasmin_ReservedWords$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_jasmin_ReservedWords$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_jasmin_ReservedWords$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern jboolean _jc_jasmin_ReservedWords$method$contains$14daef07ea176c5a(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_java__5fcup_runtime_Symbol$object *_jc_jasmin_ReservedWords$method$get$009a89eb3c60e5cc(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_jasmin_ReservedWords$vmethods {
};

// Vtable
struct _jc_jasmin_ReservedWords$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jasmin_ReservedWords$vmethods	jasmin_ReservedWords;
};

// Vtype
struct _jc_jasmin_ReservedWords$vtype {
	_jc_type			type;
	_jc_jasmin_ReservedWords$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jasmin_ReservedWords$sub_refs {
};

// Reference instance fields (object)
struct _jc_jasmin_ReservedWords$refs {
    _jc_jasmin_ReservedWords$sub_refs	jasmin_ReservedWords;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jasmin_ReservedWords$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_jasmin_ReservedWords$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jasmin_ReservedWords$sub_nonrefs	jasmin_ReservedWords;
};

// Object instance structure
struct _jc_jasmin_ReservedWords$object {
	_jc_jasmin_ReservedWords$refs	refs[0];
	_jc_word		lockword;
	_jc_jasmin_ReservedWords$vtype	*vtype;
	_jc_jasmin_ReservedWords$nonrefs	nonrefs;
};

// Type structure
extern _jc_jasmin_ReservedWords$vtype _jc_jasmin_ReservedWords$type;

// Array types class info structures
_JC_DECL_ARRAYS(jasmin_ReservedWords, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jasmin_ReservedWords$class_object;

#endif	/* _JC_jasmin_ReservedWords_H_ */
